Install Guide — Schematics 0.9.2 documentation

### Navigation

- index
- modules |
- Schematics 0.9.2 documentation »

# Install Guide

    $ pip install schematics

Python 2.6 and 2.7 are supported.

## Dependencies

Schematics has no dependencies. Regardless, we often use it with ujson or msgpack.

## Installing from Github

The canonical repository for Schematics is on Github.

    $ git clone https://github.com/j2labs/schematics.git

New releases are first released as a branch for feedback and then they are pushed into master around the same time the update is pushed to Pypi. The best reason to install from source is to help us develop Schematics. See the Developer’s Guide.

One trick the development team likes is to alias `pythisdir` to add the current directory to `$PYTHONPATH`.

    $ alias pythisdir='export PYTHONPATH=$PWD'

Between this and `virtualenv`, the authors are happy hackers.

### Navigation

- index
- modules |
- Schematics 0.9.2 documentation »